@@ -23,8 +23,10 @@ that results in a warning.
 
 """
 import warnings
+from typing import Union
 
 import numpy as np
+from numpy.typing import ArrayLike
 
 # np dtype for ecl types with fixed width
 static_dtypes = {
@@ -45,6 +47,10 @@ class MESS:
     pass
 
 
+ReadArrayValue = Union[np.ndarray, MESS]
+WriteArrayValue = Union[ArrayLike, MESS]
+
+
 def to_np_type(type_keyword):
     """
     :param type_keyword: A bytestring of a ecl type.
